Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(503)

Unified Diff: ui/app_list/views/search_result_tile_item_list_view.h

Issue 2961923002: Use EnablePlayStoreAppSearch feature flag. (Closed)
Patch Set: Oshima's comment. Created 3 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ui/app_list/app_list_features.cc ('k') | ui/app_list/views/search_result_tile_item_list_view.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/app_list/views/search_result_tile_item_list_view.h
diff --git a/ui/app_list/views/search_result_tile_item_list_view.h b/ui/app_list/views/search_result_tile_item_list_view.h
index 2b306bea4282601229d367f0c9868e0be5fa4dd0..4ad4c6013e5f865d30ae550b0002658b053013f1 100644
--- a/ui/app_list/views/search_result_tile_item_list_view.h
+++ b/ui/app_list/views/search_result_tile_item_list_view.h
@@ -48,8 +48,8 @@ class APP_LIST_EXPORT SearchResultTileItemListView
views::Textfield* search_box_; // Owned by the views hierarchy.
- // Whether the fullscreen app list feature is enabled.
- const bool is_fullscreen_app_list_enabled_;
+ // Whether the Play Store app search feature is enabled.
+ const bool is_play_store_app_search_enabled_;
DISALLOW_COPY_AND_ASSIGN(SearchResultTileItemListView);
};
« no previous file with comments | « ui/app_list/app_list_features.cc ('k') | ui/app_list/views/search_result_tile_item_list_view.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698